@@ -4,7 +4,7 @@
 # =========================================================================
 # This file is part of the GrInvIn project - http://www.grinvin.org
 # 
-# Copyright (C) 2005-2007 Universiteit Gent
+# Copyright (C) 2005-2008 Universiteit Gent
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,4 +40,4 @@ do
   CLASSPATH=$JAR:$CLASSPATH
 done
 
-java -Dgrinvin.dir=$DIRNAME org.grinvin.grinvin.Grinvin
+java -Dgrinvin.dir=$DIRNAME org.grinvin.Grinvin
